@@ -114,22 +114,13 @@ QVariant FileBrowserTreeModel::headerData(int section, Qt::Orientation orientati
 //
 void FileBrowserTreeModel::setDirTree(MyTreeType &tree) {
 
-    qDebug() << "DEBUG 1";
-
     // Clear old entries if given an empty tree
     if ( tree.count() == 0 ) {
-        qDebug() << "DEBUG 2";
-        qDebug() << (rootItem_ ? "rootItem_ ok" : "rootItem_ == 0");
         if ( rootItem_ && rootItem_->childCount() ) { // <--- THIS CAUSES CRASH!??!?!?
-            qDebug() << "DEBUG 3";
             rootItem_->child(0)->killChildren(); // <--- this causes crash!!!
-            qDebug() << "DEBUG 4";
         }
-        qDebug() << "DEBUG 5";
     }
 
-    qDebug() << "DEBUG 6";
-
     FileBrowserTreeItem* parent = 0;
     QPair < QString, QStringList > path;
     foreach (path, tree) {
