@@ -47,7 +47,7 @@ MainWindow::MainWindow(QWidget *parent)
 //                                         MCE_DEVICE_ORIENTATION_SIG,
 //                                         this,
 //                                         SLOT(orientationChanged(QString)));
-    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+    setAttribute(Qt::WA_Maemo5AutoOrientation, false);  // DISABLED BECAUSE NEW LAYOUT LOOKS LIKE SHIT ON PORTRAIT MODE!!!!
 #endif
 
     // Some signals and slots together
@@ -181,44 +181,6 @@ void MainWindow::saveAppState() const {
     sett.setValue("app/hidden", this->isHidden());
 }
 
-//
-// Orientation changing stuff for maemo 5
-//
-//#ifdef Q_WS_MAEMO_5
-//void MainWindow::setLandscape() {
-//    setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, true);
-//}
-//void MainWindow::setPortrait() {
-//    setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, true);
-//}
-//void MainWindow::orientationChanged(const QString &newOrientation)
-//{
-//    if (newOrientation == QLatin1String(MCE_ORIENTATION_PORTRAIT))
-//        setPortrait();
-//    else
-//        setLandscape();
-//}
-//bool MainWindow::event(QEvent *ev) {
-//    switch (ev->type()) {
-//    case QEvent::WindowActivate:
-//        QDBusConnection::systemBus().call(
-//                QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-//                                               MCE_REQUEST_IF,
-//                                               MCE_ACCELEROMETER_ENABLE_REQ));
-//        break;
-//    case QEvent::WindowDeactivate:
-//        QDBusConnection::systemBus().call(
-//                QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-//                                               MCE_REQUEST_IF,
-//                                               MCE_ACCELEROMETER_DISABLE_REQ));
-//        break;
-//    default:
-//        break;
-//    }
-//    return QWidget::event(ev);
-//}
-//#endif
-
 //
 // Restore size and position of the app
 //
@@ -356,6 +318,10 @@ bool MainWindow::setQmpd(Qmpd *qm) {
     connect(ui->songProgressSlider, SIGNAL(sliderPressed()), qmpd_, SLOT(onSliderPress()));
     connect(ui->songProgressSlider, SIGNAL(sliderReleased()), qmpd_, SLOT(onSliderRelease()));
 
+    // Volume
+    connect(ui->volumeSlider, SIGNAL(sliderMoved(int)), qmpd_, SLOT(onVolumeSliderMoved(int)));
+    connect(ui->volumeButton, SIGNAL(clicked()), qmpd_, SLOT(onVolumeButton()));
+
     // Playlist
     connect(ui->playlistDelAllButton, SIGNAL(clicked()), qmpd_, SLOT(onClearPlaylist()));
     connect(ui->playlistDelSelButton, SIGNAL(clicked()), this, SLOT(onDeleteSelectedFromPlaylist()));
@@ -393,6 +359,20 @@ void MainWindow::onMpdStatusChange(MpdObj *mi, ChangedStatusType what) {
     //
     // Things we do always no matter what kind of status change comes
     //
+
+    // Get volume
+    int vol = mpd_status_get_volume(qmpd_->getMpdObj());
+    if ( vol >= 0 ) {
+        ui->volumeSlider->setValue(vol);
+        if ( vol == 0 ) {
+            ui->volumeButton->setIcon(QIcon(QPixmap(":/graphics/mute.png", "PNG")));
+        }
+        else {
+            ui->volumeButton->setIcon(QIcon(QPixmap(":/graphics/volume.png", "PNG")));
+        }
+        ui->volumeButton->setIconSize(QSize(16,16));
+    }
+
     if ( currentSong_ ) {
         // Total length of playing song
         QString strDuration = currentSong_->sTime_;
@@ -650,7 +630,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
 //
 void MainWindow::setupTables() {
     ui->playlistTableview->setItemDelegate(plDelegate_);
-    ui->playlistTableview->setAlternatingRowColors(true);
+    ui->playlistTableview->setAlternatingRowColors(false);
     ui->playlistTableview->setAutoFillBackground(true);
     ui->playlistTableview->setTabKeyNavigation(false);
     ui->playlistTableview->setSelectionBehavior(QAbstractItemView::SelectRows);
@@ -699,7 +679,7 @@ void MainWindow::onSongChange(mpd_Song* song) {
     QPixmap tmpPixmap(":/unknowncoverimage");
     currentCover_ = tmpPixmap;
 #if defined (Q_WS_MAEMO_5) || defined (Q_WS_HILDON)
-    scene->addPixmap(tmpPixmap.scaled(60, 60));
+    scene->addPixmap(tmpPixmap.scaled(148, 148));
 #else
     scene->addPixmap(tmpPixmap.scaled(96, 96));
 #endif
@@ -744,7 +724,7 @@ void MainWindow::onCoverFetched(bool success) {
     currentCover_ = tmpPixmap;
     QGraphicsScene *scene = new QGraphicsScene(this);
 #if defined (Q_WS_MAEMO_5) || defined (Q_WS_HILDON)
-    scene->addPixmap(tmpPixmap.scaled(60, 60));
+    scene->addPixmap(tmpPixmap.scaled(148, 148));
 #else
     scene->addPixmap(tmpPixmap.scaled(96, 96));
 #endif
@@ -836,7 +816,7 @@ void MainWindow::onDisconnect() {
     QPixmap tmpPixmap(":/unknowncoverimage");
     currentCover_ = tmpPixmap;
 #if defined (Q_WS_MAEMO_5) || defined (Q_WS_HILDON)
-    scene->addPixmap(tmpPixmap.scaled(60, 60));
+    scene->addPixmap(tmpPixmap.scaled(148, 148));
 #else
     scene->addPixmap(tmpPixmap.scaled(96, 96));
     enableTrayControlActions(false);
@@ -908,6 +888,12 @@ bool MainWindow::connectMPD(QString host, int port, QString passwd) {
     activateUi(true);
     myShowMessage(tr("Connected to MPD succesfully!"));
 
+    // Get volume
+    int vol = mpd_status_get_volume(qmpd_->getMpdObj());
+    if ( vol >= 0 ) {
+        ui->volumeSlider->setValue(vol);
+    }
+
     // Get playlist first
     updatePlaylist(qmpd_->getMpdObj());
 
